@@ -40,7 +40,7 @@ from time import time
 import secrets
 import json
 
-__version__ = "0.0.6"
+__version__ = "0.0.7"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
@@ -83,6 +83,7 @@ if __package__:
         Logs,
         get_file_content,
         get_real_path,
+        get_encodings,
         WebScriptsConfigurationError,
         WebScriptsArgumentError,
         WebScriptsConfigurationTypeError,
@@ -98,6 +99,7 @@ else:
         Logs,
         get_file_content,
         get_real_path,
+        get_encodings,
         WebScriptsConfigurationError,
         WebScriptsArgumentError,
         WebScriptsConfigurationTypeError,
@@ -211,9 +213,9 @@ class ScriptConfig(DefaultNamespace):
         "access_users": None,
         "no_password": False,
         "description": None,
-        "category": None,
         "launcher": None,
         "timeout": None,
+        "category": "",
         "path": "",
         "args": [],
     }
@@ -249,7 +251,7 @@ class ScriptConfig(DefaultNamespace):
         args = []
         for arg in self.args:
             arg = Argument.default_build(**arg)
-            
+
             javascript_section = arg.get("javascript_section")
             if javascript_section is not None:
                 javascript_configuration = configuration.get(javascript_section)
@@ -257,7 +259,7 @@ class ScriptConfig(DefaultNamespace):
                 if not isinstance(javascript_configuration, dict):
                     raise WebScriptsConfigurationError(
                         f'"{javascript_section}" doesn\'t exist or '
-                        'is not a javascript object (a dictionnary)'
+                        "is not a javascript object (a dictionnary)"
                     )
 
                 arg.javascript_attributs = javascript_configuration
@@ -582,15 +584,28 @@ class User(DefaultNamespace):
 
     """This class implement User object"""
 
-    __required__ = ["id", "name", "groups", "csrf", "ip", "check_csrf"]
+    __required__ = [
+        "id",
+        "name",
+        "groups",
+        "csrf",
+        "ip",
+        "categories",
+        "scripts",
+        "check_csrf",
+    ]
     __types__ = {
         "id": int,
-        "groups": List[int],
         "check_csrf": bool,
+        "groups": List[int],
+        "scripts": list,
+        "categories": list,
     }
     __defaults__ = {
         "csrf": {},
         "groups": [],
+        "scripts": ["*"],
+        "categories": ["*"],
         "check_csrf": False,
     }
 
